@@ -196,38 +196,33 @@ desktop_clock_widget_free_svg_theme(DesktopClockSVGTheme* theme)
 static gboolean
 desktop_clock_widget_read_theme(DesktopClockSVGTheme* theme)
 {
-  if(!desktop_clock_widget_load_svg_file(theme->path, CLOCK_DROP_SHADOW_SVG,
-					 &theme->drop_shadow) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_FACE_SHADOW_SVG,
-					 &theme->face_shadow) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_FACE_SVG,
-					 &theme->face) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_FRAME_SVG,
-					 &theme->frame) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_GLASS_SVG,
-					 &theme->glass) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_HOUR_HAND_SHADOW_SVG,
-					 &theme->hour_hand_shadow) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_HOUR_HAND_SVG,
-					 &theme->hour_hand) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_MARKS_SVG,
-					 &theme->marks) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_MINUTE_HAND_SHADOW_SVG,
-					 &theme->minute_hand_shadow) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_MINUTE_HAND_SVG,
-					 &theme->minute_hand) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_SECOND_HAND_SHADOW_SVG,
-					 &theme->second_hand_shadow) ||
-     !desktop_clock_widget_load_svg_file(theme->path, CLOCK_SECOND_HAND_SVG,
-					 &theme->second_hand))
-  {
-    desktop_clock_widget_free_svg_theme(theme);
-    return FALSE;
-  }
-  else
-  {
-    return TRUE;
-  }
+  gboolean one_found = FALSE;
+  one_found |= desktop_clock_widget_load_svg_file(theme->path, 
+                                                  CLOCK_DROP_SHADOW_SVG,
+     					          &theme->drop_shadow);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_FACE_SHADOW_SVG,
+     					 &theme->face_shadow);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_FACE_SVG,
+     					 &theme->face);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_FRAME_SVG,
+     					 &theme->frame);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_GLASS_SVG,
+     					 &theme->glass);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_HOUR_HAND_SHADOW_SVG,
+     					 &theme->hour_hand_shadow);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_HOUR_HAND_SVG,
+     					 &theme->hour_hand);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_MARKS_SVG,
+     					 &theme->marks);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_MINUTE_HAND_SHADOW_SVG,
+     					 &theme->minute_hand_shadow);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_MINUTE_HAND_SVG,
+     					 &theme->minute_hand);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_SECOND_HAND_SHADOW_SVG,
+     					 &theme->second_hand_shadow);
+     one_found |= desktop_clock_widget_load_svg_file(theme->path, CLOCK_SECOND_HAND_SVG,
+					 &theme->second_hand);
+    return one_found; 
 }
 
 static void
@@ -556,8 +551,8 @@ desktop_clock_widget_init_theme(DesktopClockWidgetHomePlugin* desktop_plugin)
     g_object_ref(desktop_plugin->priv->minute_shadow_svg_handle);
     g_object_ref(desktop_plugin->priv->second_svg_handle);
     g_object_ref(desktop_plugin->priv->second_shadow_svg_handle);
-    desktop_clock_widget_free_svg_theme(theme);
   }
+  desktop_clock_widget_free_svg_theme(theme);
 }
 
 static int
